@@ -4,7 +4,7 @@ from pin.models import Post
 class PinForm(ModelForm):
     class Meta:
         model=Post
-        exclude = ('user', 'like', 'timestamp')
+        exclude = ('user', 'like', 'timestamp', 'category')
         
 class PinUpdateForm(ModelForm):
     class Meta:
