@@ -20,11 +20,12 @@ from django.views.decorators.csrf import csrf_exempt
 import pin_image
 from pin.crawler import get_images
 from pin.forms import PinForm, PinUpdateForm
-from pin.models import Post, Follow, Stream, Likes, Notify
+from pin.models import Post, Follow, Stream, Likes, Notify, Category
 from pin.tools import create_filename
 
 from user_profile.models import Profile
 from taggit.models import Tag
+import sys
 
 MEDIA_ROOT = settings.MEDIA_ROOT
 
@@ -241,6 +242,14 @@ def send(request):
         if form.is_valid():
             model = form.save(commit=False)
             
+            category = post_values['category']
+            if isinstance(category, string):
+                category, created = Category.objects.get_or_create(user=request.user,name=category)
+            else:
+                category = Category.objects.filter(user=request.user, id=category).all()
+                
+            model.category_id = category.id
+            
             filename= model.image
             
             image_o = "%s/pin/temp/o/%s" % ( MEDIA_ROOT,filename)
@@ -259,11 +268,19 @@ def send(request):
             return HttpResponseRedirect('/pin/')
     else:
         form = PinForm()
+    
+    user_category = Category.objects.filter(user_id=request.user.id).all()
         
     if request.is_ajax():
-        return render_to_response('pin/_send.html',{'form': form}, context_instance=RequestContext(request))
+        return render_to_response('pin/_send.html',
+                                  {'form': form,
+                                   'user_category': user_category}, 
+                                  context_instance=RequestContext(request))
     else:
-        return render_to_response('pin/send.html',{'form': form}, context_instance=RequestContext(request))
+        return render_to_response('pin/send.html',
+                                  {'form': form,
+                                   'user_category': user_category}, 
+                                  context_instance=RequestContext(request))
 
 @login_required
 def edit(request, post_id):
